# psychopy-bbtk
Extension package for adding support for devices by [Black Box ToolKit Ltd.](https://www.blackboxtoolkit.com/) to 
PsychoPy.

## Supported Devices

Installing this package alongside PsychoPy will provide support for BBTK serial devices.
    
## Installing

Install this package with the following shell command:: 

    pip install psychopy-bbtk

You may also use PsychoPy's builtin package manager to install this package.

## Usage

Once the package is installed, PsychoPy will automatically load it when started and make objects available within the
`psychopy.hardware.bbtk` namespace.

